@@ -6,13 +6,6 @@ test_that("nomis_content_type return expected format", {
 
   expect_error(nomis_content_type())
 
-  content <- nomis_content_type("sources")
-  expect_true(nrow(content) == 16)
-  expect_length(content, 6)
-  expect_type(content, "list")
-  expect_true(tibble::is_tibble(content))
-
-
   content_id <- nomis_content_type("sources", "jsa")
   expect_true(nrow(content_id) == 1)
   expect_length(content_id, 4)
