@@ -24,8 +24,4 @@ test_that("nomis_data_info return expected format", {
   expect_equal(y$id, "NM_1658_1")
   expect_true(y$uri %in% x$uri)
 
-  expect_error(
-    nomis_data_info("NM_1_6"),
-    "API request did not return any results"
-  )
 })
